@@ -3,6 +3,7 @@
 """html2text: Turn HTML into equivalent Markdown-structured text."""
 from __future__ import division
 import re
+import cgi
 
 try:
     from textwrap import wrap
@@ -28,7 +29,7 @@ from html2text.utils import (
     skipwrap
 )
 
-__version__ = "2014.12.29"
+__version__ = "2015.4.14"
 
 
 # TODO:
@@ -60,6 +61,7 @@ class HTML2Text(HTMLParser.HTMLParser):
         self.ignore_links = config.IGNORE_ANCHORS
         self.ignore_images = config.IGNORE_IMAGES
         self.images_to_alt = config.IMAGES_TO_ALT
+        self.images_with_size = config.IMAGES_WITH_SIZE
         self.ignore_emphasis = config.IGNORE_EMPHASIS
         self.bypass_tables = config.BYPASS_TABLES
         self.google_doc = False
@@ -160,10 +162,16 @@ class HTML2Text(HTMLParser.HTMLParser):
         return outtext
 
     def handle_charref(self, c):
-        self.o(self.charref(c), 1)
+        charref = self.charref(c)
+        if not self.code and not self.pre:
+            charref = cgi.escape(charref)
+        self.o(charref, 1)
 
     def handle_entityref(self, c):
-        self.o(self.entityref(c), 1)
+        entityref = self.entityref(c)
+        if not self.code and not self.pre and entityref != '&nbsp_place_holder;':
+            entityref = cgi.escape(entityref)
+        self.o(entityref, 1)
 
     def handle_starttag(self, tag, attrs):
         self.handle_tag(tag, attrs, 1)
@@ -351,6 +359,7 @@ class HTML2Text(HTMLParser.HTMLParser):
 
         if tag in ["code", "tt"] and not self.pre:
             self.o('`')  # TODO: `` `this` ``
+            self.code = not self.code
         if tag == "abbr":
             if start:
                 self.abbr_title = None
@@ -405,6 +414,20 @@ class HTML2Text(HTMLParser.HTMLParser):
                     attrs['href'] = attrs['src']
                 alt = attrs.get('alt') or ''
 
+                # If we have images_with_size, write raw html including width,
+                # height, and alt attributes
+                if self.images_with_size and \
+                        ("width" in attrs or "height" in attrs):
+                    self.o("<img src='" + attrs["src"] + "' ")
+                    if "width" in attrs:
+                        self.o("width='" + attrs["width"] + "' ")
+                    if "height" in attrs:
+                        self.o("height='" + attrs["height"] + "' ")
+                    if alt:
+                        self.o("alt='" + alt + "' ")
+                    self.o("/>")
+                    return
+
                 # If we have a link to create, output the start
                 if not self.maybe_automatic_link is None:
                     href = self.maybe_automatic_link
@@ -416,7 +439,7 @@ class HTML2Text(HTMLParser.HTMLParser):
                     else:
                         self.o("[")
                         self.maybe_automatic_link = None
-                        self.empty_link = False                   
+                        self.empty_link = False
 
                 # If we have images_to_alt, we discard the image itself,
                 # considering only the alt text.
