@@ -44,6 +44,14 @@ def main():
         default=config.IMAGES_TO_ALT,
         help="Discard image data, only keep alt text"
     )
+    p.add_option(
+        "--images-with-size",
+        dest="images_with_size",
+        action="store_true",
+        default=config.IMAGES_WITH_SIZE,
+        help="Write image tags with height and width attrs as raw html to "
+             "retain dimensions"
+    )
     p.add_option(
         "-g", "--google-doc",
         action="store_true",
@@ -118,7 +126,7 @@ def main():
 
     # process input
     encoding = "utf-8"
-    if len(args) > 0:
+    if len(args) > 0 and args[0] != '-':
         file_ = args[0]
         if len(args) == 2:
             encoding = args[1]
@@ -166,6 +174,7 @@ def main():
     h.protect_links = options.protect_links
     h.ignore_images = options.ignore_images
     h.images_to_alt = options.images_to_alt
+    h.images_with_size = options.images_with_size
     h.google_doc = options.google_doc
     h.hide_strikethrough = options.hide_strikethrough
     h.escape_snob = options.escape_snob
